==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/NUMERICFIELD_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for NUMERICFIELD_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NUMERICFIELD_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PRECISION" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="SCALE" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NUMERICFIELD_Type", propOrder = {
    "precision",
    "scale"
})
public class NUMERICFIELD_Type {

    @XmlElement(name = "PRECISION")
    protected long precision;
    @XmlElement(name = "SCALE")
    protected long scale;

    /**
     * Gets the value of the precision property.
     * 
     */
    public long getPRECISION() {
        return precision;
    }

    /**
     * Sets the value of the precision property.
     * 
     */
    public void setPRECISION(long value) {
        this.precision = value;
    }

    /**
     * Gets the value of the scale property.
     * 
     */
    public long getSCALE() {
        return scale;
    }

    /**
     * Sets the value of the scale property.
     * 
     */
    public void setSCALE(long value) {
        this.scale = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/NUMERICFIELD_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour NUMERICFIELD_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="NUMERICFIELD_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PRECISION" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="SCALE" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NUMERICFIELD_Type", propOrder = {
    "precision",
    "scale"
})
public class NUMERICFIELD_Type {

    @XmlElement(name = "PRECISION")
    protected long precision;
    @XmlElement(name = "SCALE")
    protected long scale;

    /**
     * Obtient la valeur de la propriété precision.
     * 
     */
    public long getPRECISION() {
        return precision;
    }

    /**
     * Définit la valeur de la propriété precision.
     * 
     */
    public void setPRECISION(long value) {
        this.precision = value;
    }

    /**
     * Obtient la valeur de la propriété scale.
     * 
     */
    public long getSCALE() {
        return scale;
    }

    /**
     * Définit la valeur de la propriété scale.
     * 
     */
    public void setSCALE(long value) {
        this.scale = value;
    }

}
